summaryrefslogtreecommitdiff
path: root/include/salhelper/timer.hxx
diff options
context:
space:
mode:
authorStephan Bergmann <sbergman@redhat.com>2015-02-07 12:26:56 +0100
committerStephan Bergmann <sbergman@redhat.com>2015-02-07 12:36:01 +0100
commitcfa3d6e562e758cbc18a099aa2a87309735ddf84 (patch)
tree009e9feae579712d2329d914500af640a2b0a24a /include/salhelper/timer.hxx
parent4a2f64620370587161b5437069c2f1d9f3d702d1 (diff)
loplugin:deletedspecial
Change-Id: I28d39fc455560f0ad89390bd463e0fa470dde439
Diffstat (limited to 'include/salhelper/timer.hxx')
-rw-r--r--include/salhelper/timer.hxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/salhelper/timer.hxx b/include/salhelper/timer.hxx
index 1b52522dea99..ac2a523c4b6a 100644
--- a/include/salhelper/timer.hxx
+++ b/include/salhelper/timer.hxx
@@ -212,13 +212,13 @@ protected:
private:
/** Copy constructor disabled.
*/
- SALHELPER_DLLPRIVATE Timer( const Timer& rTimer );
+ Timer( const Timer& rTimer ) SAL_DELETED_FUNCTION;
- /** Assignment operator disabled.
+ /** Copy assignment operator deleted.
*/
- SALHELPER_DLLPRIVATE void SAL_CALL operator=( const Timer& rTimer );
+ void SAL_CALL operator=( const Timer& rTimer ) SAL_DELETED_FUNCTION;
friend class TimerManager;
};
@@ -212,13 +212,13 @@ protected:
private:
- /** Copy constructor disabled.
+ /** Copy constructor deleted.
*/